from crispy_forms.helper import FormHelper
from crispy_forms.layout import Submit
from django.utils.translation import gettext as _
from django import forms
from .models import *


class RecipeForm(forms.ModelForm):
    class Meta:
        model = Recipe
        fields = ('name', 'category', 'keywords')

        labels = {
            'name': _('Name'),
            'category': _('Category'),
            'keywords': _('Keywords'),

        }

        help_texts = {
            'keywords': _('Ctrl+Click to select multiple keywords'),
        }

    def __init__(self, *args, **kwargs):
        super(RecipeForm, self).__init__(*args, **kwargs)
        self.fields['name'].widget.attrs.update({'class': 'form-control'})
        self.fields['category'].widget.attrs.update({'class': 'form-control'})
        self.fields['keywords'].widget.attrs.update({'class': 'form-control'})


class CategoryForm(forms.ModelForm):
    class Meta:
        model = Category
        fields = ('name', 'description')

        labels = {
            'name': _('Name'),
            'description': _('Description'),
        }

    def __init__(self, *args, **kwargs):
        super(CategoryForm, self).__init__(*args, **kwargs)
        self.helper = FormHelper()
        self.helper.form_method = 'post'
        self.helper.add_input(Submit('save', _('Save'), css_class='btn-primary'))


class KeywordForm(forms.ModelForm):
    class Meta:
        model = Keyword
        fields = ('name', 'description')

        labels = {
            'name': _('Name'),
            'description': _('Description'),
        }

    def __init__(self, *args, **kwargs):
        super(KeywordForm, self).__init__(*args, **kwargs)
        self.helper = FormHelper()
        self.helper.form_method = 'post'
        self.helper.add_input(Submit('save', _('Save'), css_class='btn-primary'))


class EditCategoryForm(forms.ModelForm):
    class Meta:
        model = Keyword
        fields = ('name', 'description')

        labels = {
            'name': _('Name'),
            'description': _('Description'),
        }
